import click

from reportlab.lib.units import mm

from . import nameplate
from . import ruler


@click.command()
@click.argument(
    "attendees",
    type=click.Path(
        exists=True,
        file_okay=True,
        dir_okay=False,
        writable=False,
        readable=True,
    ),
)
@click.argument(
    "logo",
    type=click.Path(
        exists=True,
        file_okay=True,
        dir_okay=False,
        writable=False,
        readable=True,
    ),
    required=False,
)
@click.option(
    "-s",
    "--size",
    type=click.INT,
    required=False,
    default=10,
    show_default="10 mm",
)
@click.option(
    "-y",
    "--adjust_y",
    type=click.INT,
    required=False,
    default=0,
    show_default=" 0 mm",
)
@click.option(
    "-x",
    "--adjust_x",
    type=click.INT,
    required=False,
    default=0,
    show_default=" 0 mm",
)
def nameplates(attendees, logo, size, adjust_x, adjust_y):
    """ creates a pdf with name plate cards

    The attendees file should be a tab separated text file with no headers. Put
    the company name in the first column, the given name in the second and the
    last name in the third column, e.g:

        Hochimin Enterprizes \\t Jane \\t Doe \\n


    The positioning of the optional logo file can be controlled with the
    size and adjustment options.
    """
    if logo is not None:
        logo = nameplate.Logo(
            logo, size * mm, adjust_x=adjust_x, adjust_y=adjust_y
        )
    npc = nameplate.NamePlateCards(logo)
    npc.generate(attendees, show=True)


@click.command()
@click.argument(
    "pdf",
    type=click.Path(
        exists=True,
        file_okay=True,
        dir_okay=False,
        writable=False,
        readable=True,
    ),
)
def addruler(pdf):
    """ adds a blue ruler overlay to a pdf file """
    ruler.ruler_overlay(pdf)
