import pdfrw
import subprocess
import tempfile

from pathlib import Path
from reportlab.pdfgen import canvas
from reportlab.lib.pagesizes import A4


def fill(original_form, values, draw_function, output_file="filled.pdf"):
    p = Path(output_file)
    if p.exists():
        p.unlink()

    with tempfile.TemporaryFile() as overlay_fh:
        with tempfile.TemporaryFile() as multipage_fh:

            # first create the pages with the values at the right positions
            # this must be done first, because we need to know the number of
            # pages
            c = canvas.Canvas(overlay_fh, pagesize=A4)
            for items in values:
                draw_function(c, items)
                c.showPage()
            c.save()
            overlay_fh.seek(0)

            olay = pdfrw.PdfReader(overlay_fh)

            # create a temporary pdf that has as many pages as the filled in
            # values
            original_form = pdfrw.PdfReader(original_form)
            writer = pdfrw.PdfWriter()
            for i in range(len(olay.pages)):
                writer.addpages(original_form.pages)
            writer.write(multipage_fh)
            multipage_fh.seek(0)

            # merge the overlay and the multipage form
            form = pdfrw.PdfReader(multipage_fh)
            for form_page, overlay_page in zip(form.pages, olay.pages):
                merge_obj = pdfrw.PageMerge()
                filled = merge_obj.add(overlay_page)[0]
                pdfrw.PageMerge(form_page).add(filled).render()

            # write the combined file to the output
            pdfrw.PdfWriter().write(output_file, form)
            subprocess.run(["open", output_file])
